prepare data for stan call
prep_data_for_rstan(mat, n_rand = 1, silent = FALSE, for_elo_model = TRUE)a list that is formatted so that it can be handed over to the respective Stan models
square interaction matrix
numeric, number of randomizations
logical, omit printing messages regarding non-fatal data
issues. Default is FALSE, i.e. do print messages.
logical, output ready for Elo steepness (default,
TRUE). If FALSE, prep for David's score steepness.