Learn R Programming

EloSteepness (version 0.5.0)

scores: numeric summaries of individual scores

Description

either based on summed winning probabilities or David's scores

Usage

scores(x, quantiles = c(0.045, 0.955), elo_scores = FALSE)

Value

a data.frame with one line per individual, providing summaries of posteriors for individual scores

Arguments

x

result from elo_steepness_from_matrix, elo_steepness_from_sequence or davids_steepness

quantiles

numeric, the quantiles to be returned

elo_scores

logical, with default FALSE. If TRUE Elo-ratings are returned, rather than the default summed winning probabilities. This argument has no consequences if x is the result of davids_steepness.

Examples

Run this code
# \donttest{
data("bonobos", package = "EloRating")
res <- davids_steepness(bonobos, refresh = 0, cores = 2)
scores(res)

data("dommats", package = "EloRating")
m <- dommats$elephants
res <- elo_steepness_from_matrix(m, n_rand = 1, refresh = 0,
                                 iter = 1000, warmup = 500)
scores(res)
# }

Run the code above in your browser using DataLab