Learn R Programming

EloSteepness (version 0.5.0)

summary.elo_steepness: summary

Description

summary

Usage

# S3 method for elo_steepness
summary(object, ...)

# S3 method for david_steepness summary(object, ...)

Value

Nothing returned. Called for side effects of textual output to console.

Arguments

object

result from elo_steepness_from_matrix, elo_steepness_from_sequence or davids_steepness

...

further arguments passed to or from other methods (ignored)